@@ -24,6 +24,7 @@ from suite_py.commands.status import Status
 from suite_py.commands.aggregator import Aggregator
 from suite_py.commands.secret import Secret
 from suite_py.commands.login import Login
+from suite_py.commands.qa import QA
 from suite_py.lib.config import Config
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
@@ -215,6 +216,60 @@ def login(obj):
     Login(obj["config"]).run()
 
 
+@main.group("qa", help="Manage QA envs")
+def qa():
+    pass
+
+
+@qa.command("update-quota", help="Update quota in QA for a user")
+@click.pass_obj
+def cli_qa_update_quota(obj):
+    QA("update-quota", obj["project"], obj["config"], obj["tokens"]).run()
+
+
+@qa.command("list", help="List QA envs for user: all to show qa of all users.")
+@click.option("-u", "--user", "user", required=False)
+@click.pass_obj
+def cli_qa_list(obj, user):
+    QA("list", obj["project"], obj["config"], obj["tokens"], user).run()
+
+
+@qa.command("create", help="Create QA env")
+@click.argument("microservices", nargs=-1, required=True)
+@click.pass_obj
+def cli_qa_create(obj, microservices):
+    QA("create", obj["project"], obj["config"], obj["tokens"], microservices).run()
+
+
+@qa.command("update", help="Update QA env")
+@click.argument("arguments", nargs=-1, required=True)
+@click.pass_obj
+def cli_qa_update(obj, arguments):
+    QA("update", obj["project"], obj["config"], obj["tokens"], arguments).run()
+
+
+@qa.command("delete", help="Delete QA env")
+@click.argument("qa_hash", required=True)
+@click.pass_obj
+def cli_qa_delete(obj, qa_hash):
+    QA("delete", obj["project"], obj["config"], obj["tokens"], qa_hash).run()
+
+
+@qa.command("check", help="Check QA conf")
+@click.pass_obj
+def cli_qa_check(obj):
+    QA("check", obj["project"], obj["config"], obj["tokens"]).run()
+
+
+@qa.command("describe", help="Describe QA environment")
+@click.argument("qa_hash", required=True)
+@click.option("--json", is_flag=True, default=False, help="Get response as JSON")
+@click.pass_obj
+def cli_qa_describe(obj, qa_hash, json):
+    flags = {"qa_hash": qa_hash, "json": json}
+    QA("describe", obj["project"], obj["config"], obj["tokens"], flags).run()
+
+
 @main.command(
     "secret", help="Manage secrets grants in multiple countries (aws-vault needed)"
 )
