@@ -38,6 +38,9 @@ class QA:
 
     def _check(self):
         r = self._qainit.execute("GET", "/api/v1/user")
+        logger.info(
+            "Checking configuration. If there is an issue, check ~/.suite_py/config.yml file and execute: suite-py login"
+        )
         logger.debug(json.dumps(r.json(), indent=2))
 
     def _list(self):
@@ -90,11 +93,11 @@ class QA:
         table.add_column("Status", style="white")
         console = Console()
 
+        r = self._qainit.execute(
+            "GET",
+            f"/api/v1/qa/{qa_hash}",
+        )
         try:
-            r = self._qainit.execute(
-                "GET",
-                f"/api/v1/qa/{qa_hash}",
-            )
             resources_list = r.json()["list"]["resources"]
             for resource in resources_list:
                 if resource["type"] == "microservice":
@@ -116,21 +119,18 @@ class QA:
                 print(json.dumps(r.json(), indent=2))
             else:
                 console.print(table)
-        except Exception as e:
-            logger.error(f"Error: {e} - {type(e)}")
+        except TypeError:
+            logger.error("Wrong hash")
 
     def _delete(self):
         qa_hash = self._flags
 
-        try:
-            r = self._qainit.execute(
-                "DELETE",
-                f"/api/v1/qa/{qa_hash}",
-            )
-            logger.info("QA deletion initiated")
-            logger.debug(json.dumps(r.json(), indent=2))
-        except Exception as e:
-            logger.error(f"Error: {e} - {type(e)}")
+        r = self._qainit.execute(
+            "DELETE",
+            f"/api/v1/qa/{qa_hash}",
+        )
+        logger.info("QA deletion initiated")
+        logger.debug(json.dumps(r.json(), indent=2))
 
     def _create(self):
         qa_default_name = f"{git.get_username()}_{self._git.current_branch_name()}"
@@ -142,18 +142,13 @@ class QA:
 
         body = {"name": f"{qa_name}", "services": srv_list}
         logger.debug(json.dumps(body))
-        try:
-            r = self._qainit.execute(
-                "POST",
-                "/api/v1/qa",
-                body=json.dumps(body),
-            )
-            logger.info("QA creation initiated")
-            logger.debug(json.dumps(r.json(), indent=2))
-        except Exception:
-            logger.error(
-                "Issue during the git command execution. please check your input"
-            )
+        r = self._qainit.execute(
+            "POST",
+            "/api/v1/qa",
+            body=json.dumps(body),
+        )
+        logger.info("QA creation initiated")
+        logger.debug(json.dumps(r.json(), indent=2))
 
     def _update(self):
         qa_hash = self._flags[0]
@@ -163,17 +158,13 @@ class QA:
 
         body = {"services": srv_list}
         logger.debug(json.dumps(body))
-        try:
-            r = self._qainit.execute(
-                "PUT",
-                f"/api/v1/qa/{qa_hash}",
-                body=json.dumps(body),
-            )
-            logger.debug(json.dumps(r.json(), indent=2))
-        except Exception:
-            logger.error(
-                "Issue during the git command execution. please check your input"
-            )
+        r = self._qainit.execute(
+            "PUT",
+            f"/api/v1/qa/{qa_hash}",
+            body=json.dumps(body),
+        )
+        logger.info("QA update initiated")
+        logger.debug(json.dumps(r.json(), indent=2))
 
     def _update_quota(self):
         username = prompt_utils.ask_questions_input("Insert GitHub username: ")
